Faraday class
核心入口类
Constructors
- Faraday()
-
备用 后续会创建faraday注解
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → void - 刷新页面
-
toString(
) → String -
A string representation of this object.
inherited
-
wrapper(
RouteFactory rawFactory, {ColorProvider? nativeContainerBackgroundColorProvider, TransitionBuilderProvider? switchPageAnimation, List< NavigatorObserver> ? observers, WidgetBuilder? errorPage, }) → Route -
Flutter Native 容器: iOS端是指FlutterViewControllerAndroid端是指FlutterActivity或者FlutterFragment容器初始化时需要指定name以及arguments以下统一简称容器
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- topContext → BuildContext?
-
最上层 context
no setter
-
最上层 navigator
no setter